@@ -1,6 +1,6 @@
 utils::globalVariables(c(
-  ".", "from", "i.module", "i.objectClass", "module", "module.x", "module.y",
-  "name", "objectClass", "objectName", "other", "sourceURL", "to"
+  ".", "from", "fromOrd", "i.module", "i.objectClass", "module", "module.x", "module.y",
+  "name", "objectClass", "objectName", "other", "sourceURL", "to", "toOrd"
 ))
 
 # register the S3 `igraph` class for use with S4 methods.
@@ -39,6 +39,10 @@ setMethod(
   definition = function(sim, plot) {
     deps <- sim@depends
     DT <- .depsEdgeList(deps, plot)
+    correctOrd <- unlist(sim@modules, use.names = FALSE)
+    DT[, fromOrd := factor(from, levels = correctOrd)]
+    DT[, toOrd := factor(to, levels = correctOrd)]
+    DT <- setorderv(DT, c("fromOrd", "toOrd"))
     return(DT)
 })
 
@@ -115,9 +119,9 @@ setMethod("depsGraph",
             if (plot) {
               el <- depsEdgeList(sim, plot)
             } else {
-              el <- depsEdgeList(sim, plot) %>% .depsPruneEdges()
+              el <- depsEdgeList(sim, plot) |> .depsPruneEdges()
             }
-            m <- modules(sim) %>% unlist() # modules(sim) doesn't return hidden modules
+            m <- modules(sim) |> unlist() # modules(sim) doesn't return hidden modules
             v <- unique(c(el$to, el$from, m)) # so no need to remove them
             return(graph_from_data_frame(el, vertices = v, directed = TRUE))
 })
@@ -173,16 +177,16 @@ setMethod(
                                    to = colnames(M)[col])$vpath[[1]]
             pth1 <- data.frame(from = rownames(M)[pth1],
                                to = rownames(M)[shift(match(names(pth1), rownames(M)), -1)],
-                               stringsAsFactors = FALSE) %>%
-                    na.omit() %>% as.data.table()
+                               stringsAsFactors = FALSE) |>
+                    na.omit() |> as.data.table()
 
             pth2 <- shortest_paths(simGraph,
                                    from = colnames(M)[col],
                                    to = rownames(M)[row])$vpath[[1]]
             pth2 <- data.frame(from = rownames(M)[pth2],
                                to = rownames(M)[shift(match(names(pth2), rownames(M)), -1)],
-                               stringsAsFactors = FALSE) %>%
-                    na.omit() %>% as.data.table()
+                               stringsAsFactors = FALSE) |>
+                    na.omit() |> as.data.table()
 
             pth <- rbindlist(list(pth, rbindlist(list(pth1, pth2))))
           }
@@ -191,25 +195,24 @@ setMethod(
       pth <- unique(pth)
       pth <- simEdgeList[pth, on = c("from", "to")]
 
-      # what is not provided in modules, but needed
-      # missingObjects <- simEdgeList %>% filter(from != to) %>%
-      #   anti_join(pth, ., by = c("from", "to"))
+      ## what is not provided in modules, but needed
       missingObjects <- pth[!simEdgeList[from != to], on = c("from", "to")]
       if (nrow(missingObjects)) {
         warning("Problem resolving the module dependencies:\n",
                 paste(missingObjects), collapse = "\n")
       }
 
-      # what is provided in modules, and can be omitted from simEdgeList object
-      # newEdgeList <- simEdgeList %>%
-      #   filter(from != to) %>%
-      #   anti_join(pth, by = c("from", "to"))
+      ## what is provided in modules, and can be omitted from simEdgeList object
       newEdgeList <- simEdgeList[from != to][!pth, on = c("from", "to")]
 
     } else {
       newEdgeList <- simEdgeList
     }
-    return(newEdgeList %>% data.table() %>% setorder("from", "to", "objName"))
+
+    newEdgeList <- newEdgeList |> setorder("fromOrd", "toOrd", "objName")
+    newEdgeList <- newEdgeList[, `:=`(fromOrd = as.character(fromOrd), toOrd = as.character(toOrd))]
+
+    return(newEdgeList)
 })
 
 ################################################################################
@@ -276,12 +279,13 @@ setMethod(".depsLoadOrder",
                   }
               }
             }
-            if (doTopoSort)
+            if (doTopoSort) {
               tsort <- topo_sort(simGraph, "out")
+            }
 
             # depsGrDF <- as.data.table(as_data_frame(simGraph))
             if (length(tsort)) {
-              loadOrder <- names(simGraph[[tsort, ]]) %>% .[!(. %in% "_INPUT_" )]
+              loadOrder <- names(simGraph[[tsort, ]]) |> (function(x) x[!(x %in% "_INPUT_")])()
             } else {
               modules <- unlist(sim@modules)
               if (length(sim@modules)) {
@@ -332,10 +336,3 @@ setMethod(".depsLoadOrder",
             }
             return(loadOrder)
 })
-
-.rndstr <- function(n = 1, len = 8) {
-  unlist(lapply(character(n), function(x) {
-    x <- paste0(sample(c(0:9, letters, LETTERS), size = len,
-                       replace = TRUE), collapse = "")
-  }))
-}
