@@ -1,4 +1,8 @@
-################################################################################
+#' @keywords internal
+openIsRequested <- function(open, suff) {
+  isTRUE(open) || endsWith(tolower(open), suff)
+}
+
 #' Open a file for editing
 #'
 #' RStudio's `file.edit` behaves differently than `utils::file.edit`.
@@ -12,21 +16,17 @@
 #' @importFrom utils file.edit
 #' @keywords internal
 #' @rdname fileEdit
-#'
 .fileEdit <- function(file) {
   if (Sys.getenv("RSTUDIO") == "1") {
     file <- gsub(file, pattern = "\\./", replacement = "")
     file.show(file)
-    message("Using RStudio; may need to open manually e.g., with file.edit or file.show")#,
-#            paste0("file.edit('", file, "')")
-#    )
+    message("Using RStudio; may need to open manually e.g., with file.edit or file.show")
   } else {
     file.edit(file)
   }
   message(paste0("file.edit('", file, "')"))
 }
 
-################################################################################
 #' Create new module from template
 #'
 #' Generate a skeleton for a new SpaDES module, a template for a
@@ -35,10 +35,9 @@
 #' The `newModuleDocumentation` will not generate the module file, but will
 #' create the other files.
 #'
-#' All files will be created within a subdirectory named `name` within the
-#' `path`:
+#' All files will be created within a subdirectory named `name` within the `path`:
 #'
-#' \preformatted{
+#' ```
 #'   <path>/
 #'     |_ <name>/
 #'     |_ R/               # contains additional module R scripts
@@ -50,14 +49,16 @@
 #'     |_ README.md        # provide overview of key aspects
 #'     |_ <name>.R         # module code file (incl. metadata)
 #'     |_ <name>.Rmd       # documentation, usage info, etc.
-#' }
+#' ```
 #'
 #' @param name  Character string specifying the name of the new module.
 #'
 #' @param path  Character string. Subdirectory in which to place the new module code file.
 #'              The default is the current working directory.
 #'
-#' @param ...   Additional arguments. Currently, only the following are supported:\cr\cr
+#' @param ...   Additional arguments. Currently, these can be either named
+#'    function definitions (which will be added to the `simList`) or one or
+#'    more of the following:\cr\cr
 #' \describe{
 #'   \item{`children`}{Required when `type = "parent"`. A character vector
 #'   specifying the names of child modules.}
@@ -71,7 +72,13 @@
 #'   Default `TRUE`.}
 #' }
 #'
-#' @return Nothing is returned. The new module file is created at
+#' @param events A list of named expressions, each of which is surrounded by `{ }`.
+#'   A user can specify events here, instead of accepting the default `doEvent` function
+#'   that comes with the module template. See example.
+#' @param envir An environment where objects being passed to `newModule` can be found.
+#'   Default `parent.frame()`, which should be fine for most cases.
+#'
+#' @return NULL (invisibly). The new module file is created at
 #' \file{path/name.R}, as well as ancillary files for documentation, citation,
 #' \file{LICENSE}, \file{README}, and \file{tests} directory.
 #'
@@ -98,7 +105,7 @@
 #'   unlink(tmpdir, recursive = TRUE)
 #' }
 #'
-setGeneric("newModule", function(name, path, ...) {
+setGeneric("newModule", function(name, path, ..., events, envir = parent.frame()) {
   standardGeneric("newModule")
 })
 
@@ -108,59 +115,82 @@ setGeneric("newModule", function(name, path, ...) {
 setMethod(
   "newModule",
   signature = c(name = "character", path = "character"),
-  definition = function(name, path, ...) {
-    args <- list(...)
+  definition = function(name, path, ..., events, envir) {
+    events <- substitute(events)
+    argsFull <- substitute(list(...))
+    argsNames <- ...names()
 
-    stopifnot((names(args) %in% c("children", "open", "type", "unitTests", "useGitHub")))
+    simpleArgs <- c("children", "open", "type", "unitTests", "useGitHub")
+    simpleArgsHere <- intersect(argsNames, simpleArgs)
+    args <- eval(as.list(argsFull[simpleArgsHere]))
+    args <- lapply(args, eval, envir = envir) # Things like T --> TRUE
 
-    children <- args$children
-    open <- args$open
-    type <- args$type
-    unitTests <- args$unitTests
-    useGitHub <- args$useGitHub
+    argsOther <- as.list(argsFull[setdiff(argsNames, simpleArgsHere)])
+    if (any(sapply(argsOther, is.null))) {
+      a <- argsFull[-1][!nzchar(names(argsFull[-1]))]
+      if (any(grepl("<-", a[[1]][[1]])))
+        stop("Did you use `<-` operator instead of `=` for arguments?")
+    }
+    # args <- list(...)
 
-    # define defaults for ... args
-    if (is.null(children)) children <- NA_character_
-    if (is.null(open)) open <- interactive()
-    if (is.null(type)) type <- "child"
-    if (is.null(unitTests)) unitTests <- TRUE
-    if (is.null(useGitHub)) useGitHub <- TRUE
+    stopifnot(all(names(args) %in% simpleArgs))
+
+    ## define defaults for ... args
+    if (is.null(args$children)) args$children <- NA_character_
+    if (is.null(args$open)) {
+      args$open <- open.user <- interactive()
+    } else {
+      open.user <- args$open
+    }
+    if (is.null(args$type)) args$type <- "child"
+    if (is.null(args$unitTests)) args$unitTests <- TRUE
+    if (is.null(args$useGitHub)) args$useGitHub <- TRUE
 
     stopifnot(
-      is(children, "character"),
-      is(open, "logical") || any(endsWith(tolower(open), c("r", "rmd"))),
-      is(type, "character"),
-      type %in% c("child", "parent"),
-      is(unitTests, "logical"),
-      is(useGitHub, "logical")
+      is(args$children, "character"),
+      is(args$open, "logical") || any(endsWith(tolower(args$open), c("r", "rmd"))),
+      is(args$type, "character"),
+      args$type %in% c("child", "parent"),
+      is(args$unitTests, "logical"),
+      is(args$useGitHub, "logical")
     )
 
     path <- checkPath(path, create = TRUE)
-    nestedPath <- file.path(path, name) %>% checkPath(create = TRUE)
-    dataPath <- file.path(nestedPath, "data") %>% checkPath(create = TRUE)
-    RPath <- file.path(nestedPath, "R") %>% checkPath(create = TRUE)
+    nestedPath <- file.path(path, name) |> checkPath(create = TRUE)
+    dataPath <- file.path(nestedPath, "data") |> checkPath(create = TRUE)
+    RPath <- file.path(nestedPath, "R") |> checkPath(create = TRUE)
 
     ## empty data checksum file
     cat("", file = file.path(dataPath, "CHECKSUMS.txt"))
 
-    if (isTRUE(useGitHub)) {
+    if (isTRUE(args$useGitHub)) {
       ## basic .gitignore file for module data
       gitignoreTemplate <- readLines(file.path(.pkgEnv[["templatePath"]], "data-gitignore.template"))
       writeLines(whisker.render(gitignoreTemplate), file.path(dataPath, ".gitignore"))
     }
 
     ## module code file
-    newModuleCode(name = name, path = path, open = isTRUE(open) || endsWith(tolower(open), "r"),
-                  type = type, children = children)
+    args$open <- openIsRequested(open.user, suff = "r")
+    do.call(newModuleCode, append(alist(name = name, path = path, events = events),
+                                  append(args, argsOther)))
 
-    if (type == "child" && unitTests) {
-      newModuleTests(name = name, path = path, open = !isFALSE(open), useGitHub = useGitHub)
+    if (!args$open) {
+      message("Main module file is: ", normalizePath(file.path(path, name, paste0(name, ".R"))))
+    }
+
+    if (args$type == "child" && args$unitTests) {
+      newModuleTests(name = name, path = path, open = !isFALSE(args$open), useGitHub = args$useGitHub)
     }
 
     ### Make R Markdown file for module documentation
+    args$open <- openIsRequested(open.user, suff = "rmd")
     newModuleDocumentation(name = name, path = path,
-                           open = isTRUE(open) || endsWith(tolower(open), "rmd"),
-                           type = type, children = children)
+                           open = args$open, type = args$type, children = args$children)
+    if (!args$open) {
+      message("Main documentation file is: ", normalizePath(file.path(path, name, paste0(name, ".Rmd"))))
+    }
+
+    return(invisible(NULL))
 })
 
 #' @export
@@ -168,11 +198,10 @@ setMethod(
 setMethod(
   "newModule",
   signature = c(name = "character", path = "missing"),
-  definition = function(name, ...) {
-    newModule(name = name, path = , ...)
+  definition = function(name, ..., events = list(), envir) {
+    newModule(name = name, path = ".", ..., events = events, envir = envir)
 })
 
-################################################################################
 #' Create new module code file
 #'
 #' @param name  Character string specifying the name of the new module.
@@ -180,52 +209,74 @@ setMethod(
 #' @param path  Character string. Subdirectory in which to place the new module code file.
 #'              The default is the current working directory.
 #'
-#' @param open  Logical. Should the new module file be opened after creation?
-#'              Default `TRUE` in an interactive session.
+#' @param ...   Additional arguments. Currently, these can be either named
+#'    function definitions (which will be added to the `simList`) or one or
+#'    more of the following:\cr\cr
+#' \describe{
+#'   \item{`children`}{Required when `type = "parent"`. A character vector
+#'   specifying the names of child modules.}
+#'   \item{`open`}{Logical. Should the new module file be opened after creation?
+#'   Default `TRUE`.}
+#'   \item{`type`}{Character string specifying one of `"child"` (default),
+#'   or `"parent"`.}
+#' }
 #'
-#' @param type  Character string specifying one of `"child"` (default),
-#'              or `"parent"`.
+#' @param events A list of named expressions, each of which is surrounded by `{ }`.
+#'   A user can specify events here, instead of accepting the default `doEvent` function
+#'   that comes with the module template. See example for [newModule()].
 #'
-#' @param children   Required when `type = "parent"`. A character vector
-#'                   specifying the names of child modules.
-#'
-#' @return Nothing is returned. Invoked for its side effect of creating new module code files.
+#' @return NULL (invisibly). Invoked for its side effect of creating new module code files.
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @export
 #' @rdname newModuleCode
-setGeneric("newModuleCode", function(name, path, open, type, children) {
+setGeneric("newModuleCode", function(name, path, ..., events) {
   standardGeneric("newModuleCode")
 })
 
 #' @export
 #' @family module creation helpers
-#' @importFrom crayon bold green yellow
+#' @importFrom cli col_green col_yellow style_bold
 #' @importFrom reproducible checkPath
 #' @importFrom whisker whisker.render
 #' @rdname newModuleCode
-# igraph exports %>% from magrittr
 setMethod(
   "newModuleCode",
-  signature = c(name = "character", path = "character", open = "logical",
-                type = "character", children = "character"),
-  definition = function(name, path, open, type, children) {
-    stopifnot(type %in% c("child", "parent"))
+  signature = c(name = "character", path = "character"),
+  definition = function(name, path, ..., events) {
+    argsFull <- list(...)
+    argsNames <- ...names()
+    simpleArgs <- c("children", "open", "type")
+    simpleArgsHere <- intersect(argsNames, simpleArgs)
+    args <- eval(as.list(argsFull[simpleArgsHere]))
+
+    stopifnot(all(names(args) %in% simpleArgs))
+
+    ## define defaults for ... args
+    if (is.null(args$children)) args$children <- NA_character_
+    if (is.null(args$open)) {
+      args$open <- open.user <- interactive()
+    } else {
+      open.user <- args$open
+    }
+    if (is.null(args$type)) args$type <- "child"
+
+    stopifnot(args$type %in% c("child", "parent"))
 
     path <- checkPath(path, create = TRUE)
-    nestedPath <- file.path(path, name) %>% checkPath(create = TRUE)
+    nestedPath <- file.path(path, name) |> checkPath(create = TRUE)
     filenameR <- file.path(nestedPath, paste0(name, ".R"))
 
-    children_char <- if (any(is.na(children)) || length(children) == 0L) {
+    children_char <- if (any(is.na(args$children)) || length(args$children) == 0L) {
       "character(0)"
     } else {
-      capture.output(dput(children))
+      capture.output(dput(args$children))
     }
 
     version <- list()
     version[[name]] <- moduleDefaults[["version"]]
-    if (type == "parent")
-      lapply(children, function(x) version[[x]] <<- "0.0.1")
+    if (args$type == "parent")
+      lapply(args$children, function(x) version[[x]] <<- "0.0.1")
 
     SpaDES.core.version <- as.character(utils::packageVersion("SpaDES.core"))
     DESCtxt <- readLines(system.file("DESCRIPTION", package = "SpaDES.core"))
@@ -245,7 +296,7 @@ setMethod(
     )
     modulePartialMetaTemplate <- readLines(file.path(.pkgEnv[["templatePath"]],
                                                      "modulePartialMeta.R.template"))
-    otherMetadata <- if (type == "child") {
+    otherMetadata <- if (args$type == "child") {
       whisker.render(modulePartialMetaTemplate, modulePartialMeta)
     } else {
       paste("## this is a parent module and as such does not have any",
@@ -256,14 +307,73 @@ setMethod(
       name = name,
       name_char = deparse(name)
     )
-    moduleEventsTemplate <- readLines(file.path(.pkgEnv[["templatePath"]],
-                                                "modulePartialEvents.R.template"))
-    moduleEvents <- if (type == "child") {
+
+    templDE <- "doEvent"
+    templs <- c("Init", "Save", "plotFn", "Event1", "Event2", ".inputObjects", "ggplotFn")
+    moduleTmplTxt <- list()
+    for (templ in c(templDE, templs)) {
+      moduleTmplTxt[[templ]] <- readLines(file.path(.pkgEnv[["templatePath"]],
+                                                    paste0("module", templ, ".R.template")))
+    }
+
+    if (!missing(events)) {
+      evs <- names(events)[nzchar(names(events))]
+      ord <- c(evs, templs)
+      if (length(evs)) {
+        moduleTmplTxt[["doEvent"]] <- NULL
+        for (n in evs) {
+          #   defineEvent(code = events[[n]], eventName = n, moduleName = name)
+
+          eventFnName <-  makeEventFn(name, n)
+          moduleTmplTxt[[n]] <- defineEventFnMaker(events[[n]], eventFnName)
+        }
+      } else {
+        stop("events must be a list of named elements, where each name is the event name")
+      }
+
+      ord <- intersect(ord, names(moduleTmplTxt))
+      moduleTmplTxt <- moduleTmplTxt[ord]
+
+      # b <- lapply(events, substitute)
+
+      if (!is.null(...names())) {
+        other <- ...names()[nzchar(...names())]
+        ord <- c(templDE, evs, other, templs)
+        if (length(other)) {
+          for (n in other) {
+            ## defineEventFnMaker(events[[n]], eventFnName)
+            moduleTmplTxt[[n]] <- paste0(n, " <- ", paste(format(argsFull[[n]]), collapse = "\n"))
+          }
+        }
+
+        ord <- intersect(ord, names(moduleTmplTxt))
+        moduleTmplTxt <- moduleTmplTxt[ord]
+      }
+    }
+
+    moduleEventsTemplate <- unlist(moduleTmplTxt, use.names = FALSE)
+
+    moduleEvents <- if (args$type == "child") {
       whisker.render(moduleEventsTemplate, modulePartialEvents)
     } else {
       "## this is a parent module and as such does not have any events."
     }
 
+    # if (length(argsNames)) {
+    #
+    #   pp <- parse(text = moduleEvents)
+    #   doEvent <- grep("doEvent\\.", pp)
+    #   df <- deparse(as.list(argsFull)[[argsNames]])
+    #   # fn <- defineEventFnMaker(df)
+    #   eventFnName <-  makeEventFn(name, argsNames)
+    #   fn <- defineEventFnMaker(df, eventFnName)
+    #
+    #   pp[[doEvent]] <- fn
+    #   eventFnName <-  makeEventFn(name, argsNames)
+    #
+    #
+    # }
+
     moduleData <- list(
       authors = deparse(moduleDefaults[["authors"]], width.cutoff = 500),
       children = children_char,
@@ -276,35 +386,47 @@ setMethod(
       RmdName = deparse(paste0(name, ".Rmd")),
       timeframe = deparse(moduleDefaults[["timeframe"]]),
       timeunit = deparse(moduleDefaults[["timeunit"]]),
-      type = type,
+      type = args$type,
       versions = deparse(version)
     )
     moduleTemplate <- readLines(file.path(.pkgEnv[["templatePath"]], "module.R.template"))
     writeLines(whisker.render(moduleTemplate, moduleData), filenameR)
 
     ## help the user with next steps
-    message(crayon::bold(paste(
-      crayon::green("New module"),
-      crayon::yellow(name),
-      crayon::green("created at"),
-      crayon::yellow(dirname(nestedPath))
+    message(cli::style_bold(paste(
+      cli::col_green("New module"),
+      cli::col_yellow(name),
+      cli::col_green("created at"),
+      cli::col_yellow(dirname(nestedPath))
     )))
-    message(crayon::green("* edit module code in", crayon::yellow(paste0(name, ".R"))))
-    message(crayon::green("* write tests for your module code in", crayon::yellow("tests/")))
-    message(crayon::green("* describe and document your module in", crayon::yellow(paste0(name, ".Rmd"))))
-    message(crayon::green("* tell others how to cite your module by editing", crayon::yellow("citation.bib")))
-    message(crayon::green("* choose a license for your module; see", crayon::yellow("LICENSE.md")))
+    message(paste(
+      cli::col_green("* edit module code in"), cli::col_yellow(paste0(name, ".R"))
+    ))
+    message(paste(
+      cli::col_green("* write tests for your module code in"), cli::col_yellow("tests/")
+    ))
+    message(paste(
+      cli::col_green("* describe and document your module in"), cli::col_yellow(paste0(name, ".Rmd"))
+    ))
+    message(paste(
+      cli::col_green("* tell others how to cite your module by editing"), cli::col_yellow("citation.bib")
+    ))
+    message(paste(
+      cli::col_green("* choose a license for your module; see"), cli::col_yellow("LICENSE.md")
+    ))
 
-    if (isTRUE(open)) {
+    if (isTRUE(args$open)) {
       openModules(name, nestedPath)
     }
+
+    return(invisible(NULL))
 })
 
 #' Create new module documentation
 #'
 #' @inheritParams newModuleCode
 #'
-#' @return Nothing is returned. Invoked for its side effect of creating new module code files.
+#' @return NULL (invisibly). Invoked for its side effect of creating new module code files.
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @importFrom reproducible checkPath
@@ -312,7 +434,7 @@ setMethod(
 #' @family module creation helpers
 #' @rdname newModuleDocumentation
 #'
-setGeneric("newModuleDocumentation", function(name, path, open, type, children) {
+setGeneric("newModuleDocumentation", function(name, path, ...) {
   standardGeneric("newModuleDocumentation")
 })
 
@@ -320,11 +442,25 @@ setGeneric("newModuleDocumentation", function(name, path, open, type, children)
 #' @rdname newModuleDocumentation
 setMethod(
   "newModuleDocumentation",
-  signature = c(name = "character", path = "character", open = "logical",
-                type = "character", children = "character"),
-  definition = function(name, path, open, type, children) {
+  signature = c(name = "character", path = "character"),
+  definition = function(name, path, ...) {
+    argsFull <- list(...)
+    argsNames <- ...names()
+    simpleArgs <- c("children", "open", "type")
+    simpleArgsHere <- intersect(argsNames, simpleArgs)
+    args <- eval(as.list(argsFull[simpleArgsHere]))
+
+    stopifnot(all(names(args) %in% simpleArgs))
+
+    ## define defaults for ... args
+    if (is.null(args$children)) args$children <- NA_character_
+    if (is.null(args$open)) args$open <- interactive()
+    if (is.null(args$type)) args$type <- "child"
+
+    stopifnot(args$type %in% c("child", "parent"))
+
     path <- checkPath(path, create = TRUE)
-    nestedPath <- file.path(path, name) %>% checkPath(create = TRUE)
+    nestedPath <- file.path(path, name) |> checkPath(create = TRUE)
     filenameRmd <- file.path(nestedPath, paste0(name, ".Rmd"))
     filenameCitation <- file.path(nestedPath, "citation.bib")
     filenameLICENSE <- file.path(nestedPath, "LICENSE.md")
@@ -369,7 +505,7 @@ setMethod(
       writeLines(whisker.render(ReadmeTemplate, moduleRmd), filenameREADME)
     }
 
-    if (open) {
+    if (args$open) {
       openModules(basename(filenameRmd), nestedPath)
     }
 
@@ -379,25 +515,9 @@ setMethod(
 #' @export
 #' @rdname newModuleDocumentation
 setMethod("newModuleDocumentation",
-          signature = c(name = "character", path = "missing", open = "logical"),
-          definition = function(name, open) {
-            newModuleDocumentation(name = name, path = ".", open = open)
-})
-
-#' @export
-#' @rdname newModuleDocumentation
-setMethod("newModuleDocumentation",
-          signature = c(name = "character", path = "character", open = "missing"),
-          definition = function(name, path) {
-            newModuleDocumentation(name = name, path = path, open = interactive())
-})
-
-#' @export
-#' @rdname newModuleDocumentation
-setMethod("newModuleDocumentation",
-          signature = c(name = "character", path = "missing", open = "missing"),
-          definition = function(name) {
-            newModuleDocumentation(name = name, path = ".", open = interactive())
+          signature = c(name = "character", path = "missing"),
+          definition = function(name, ...) {
+            newModuleDocumentation(name = name, path = ".", ...)
 })
 
 #' Use GitHub actions for automated module checking
@@ -437,7 +557,7 @@ use_gha <- function(name, path) {
 #'                  If `TRUE` (default), creates suitable configuration files (e.g.,
 #'                  \file{.gitignore}) and configures basic GitHub actions for module code checking.
 #'
-#' @return Nothing is returned. Invoked for its side effect of creating new module test files.
+#' @return NULL (invisibly). Invoked for its side effect of creating new module test files.
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @importFrom reproducible checkPath
@@ -459,7 +579,7 @@ setMethod(
       warning('The `testthat` package is required to run unit tests on modules.')
     }
     path <- checkPath(path, create = TRUE)
-    testthatDir <- file.path(path, name, "tests", "testthat") %>% checkPath(create = TRUE)
+    testthatDir <- file.path(path, name, "tests", "testthat") |> checkPath(create = TRUE)
     testDir <- dirname(testthatDir)
 
     ## create basic local testing structure based on testthat
@@ -479,6 +599,8 @@ setMethod(
     if (isTRUE(useGitHub)) {
       use_gha(name, path)
     }
+
+    return(invisible(NULL))
 })
 
 #' Open all modules nested within a base directory
@@ -493,7 +615,7 @@ setMethod(
 #' @param path  Character string of length 1. The base directory within which
 #'              there are only module subdirectories.
 #'
-#' @return Nothing is returned. All file are open via `file.edit`.
+#' @return NULL (invisibly). All file are open via `file.edit`.
 #'
 #' @note On Windows there is currently a bug in RStudio that prevents the editor
 #' from opening when `file.edit` is called. `file.edit` does work if the
@@ -556,6 +678,8 @@ setMethod(
 
     lapply(file.path(basedir, Rfiles), .fileEdit)
     setwd(origDir)
+
+    return(invisible(NULL))
 })
 
 #' @export
@@ -687,7 +811,7 @@ setMethod("copyModule",
 #'                e.g., add `"-q"` using `flags="-q -r9X"`
 #'                (the default flags are `"-r9X"`).
 #'
-#' @return Nothing is returned. Invoked for its side effect of zipping module files.
+#' @return NULL (invisibly). Invoked for its side effect of zipping module files.
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @export
@@ -712,7 +836,7 @@ setMethod(
     on.exit(setwd(callingWd), add = TRUE)
     setwd(path)
     zipFileName <- paste0(name, "_", version, ".zip")
-    message(crayon::green(paste("Zipping module into zip file:", zipFileName)), sep = "")
+    message(cli::col_green(paste("Zipping module into zip file:", zipFileName)), sep = "")
 
     allFiles <- dir(path = file.path(name), recursive = TRUE, full.names = TRUE)
 
@@ -734,6 +858,8 @@ setMethod(
     }
     file.copy(zipFileName, to = paste0(name, "/", zipFileName), overwrite = TRUE)
     file.remove(zipFileName)
+
+    return(invisible(NULL))
 })
 
 #' @rdname zipModule
@@ -757,6 +883,6 @@ setMethod("zipModule",
 setMethod("zipModule",
           signature = c(name = "character", path = "character", version = "missing"),
           definition = function(name, path, data, ...) {
-            vers <- moduleVersion(name, path) %>% as.character()
+            vers <- moduleVersion(name, path) |> as.character()
             zipModule(name = name, path = path, version = vers, data = data, ...)
 })
