@@ -15,7 +15,7 @@ utils::globalVariables(".")
 setGeneric(".unparsed",
            function(modules) {
              standardGeneric(".unparsed")
-           })
+})
 
 #' @rdname unparsed
 setMethod(
@@ -24,9 +24,11 @@ setMethod(
   definition = function(modules) {
     ids <- lapply(modules, function(x) {
       (attr(x, "parsed") == FALSE)
-    }) %>% `==`(., TRUE) %>% which()
+    }) |>
+      (function(x) x == TRUE)() |>
+      which()
     return(ids)
-  })
+})
 
 #' @param filename The filename of the module to be parsed.
 #'
@@ -180,7 +182,7 @@ setMethod(
 #' @return A `simList` simulation object.
 #'
 #' @author Alex Chubaty and Eliot McIntire
-#' @importFrom crayon blue green
+#' @importFrom cli col_blue col_green
 #' @importFrom reproducible Cache
 #' @include environment.R
 #' @include module-dependencies-class.R
@@ -252,7 +254,7 @@ setMethod(
           if (!requireNamespace("roxygen2")) stop("Please install.packages(c('roxygen2'))")
           namespaceFile <- dir(m, pattern = "NAMESPACE")
           if (isTRUE(getOption("spades.moduleDocument", NULL)) || length(namespaceFile) == 0) {
-            message(crayon::blue("    To skip rebuilding documentation, set options('spades.moduleDocument' = FALSE)"))
+            message(cli::col_blue("    To skip rebuilding documentation, set options('spades.moduleDocument' = FALSE)"))
             roxygen2::roxygenise(m, roclets = NULL) # This builds documentation, but also exports all functions ...
             pkgload::dev_topic_index_reset(m)
             pkgload::unload(.moduleNameNoUnderscore(mBase)) # so, unload here before reloading without exporting
@@ -287,7 +289,7 @@ setMethod(
 
           # evaluate the rest of the parsed file
           if (doesntUseNamespacing) {
-            stop("Module ", crayon::green(mBase), " still uses the old way of function naming.\n  ",
+            stop("Module ", cli::col_green(mBase), " still uses the old way of function naming.\n  ",
                  "It is now recommended to define functions that are not prefixed with the module name\n  ",
                  "and to no longer call the functions with sim$functionName.\n  ",
                  "Simply call functions in your module with their name: e.g.,\n  ",
@@ -421,26 +423,32 @@ setMethod(
         # do inputObjects and outputObjects
         pf <- tmp$pf # tmp[["parsedFile"]][tmp[["defineModuleItem"]]]
         if (any(inObjs)) {
+          evald <- try(eval(pf[[1]][[3]][inObjs][[1]]), silent = TRUE)
+          if (is(evald, "try-error")) stop("In ", mBase, " in the `inputObjects`:",
+                                           "\n", evald)
           sim@depends@dependencies[[i]]@inputObjects <- data.frame(
             rbindlist(fill = TRUE,
                       list(sim@depends@dependencies[[i]]@inputObjects,
-                           eval(pf[[1]][[3]][inObjs][[1]]))
+                           evald)
             )
           )
         }
 
         if (any(outObjs)) {
+          evald <- try(eval(pf[[1]][[3]][outObjs][[1]]), silent = TRUE)
+          if (is(evald, "try-error")) stop("In ", mBase, " in the `outputObjects`:",
+                                           "\n", evald)
           sim@depends@dependencies[[i]]@outputObjects <- data.frame(
             rbindlist(fill = TRUE,
                       list(sim@depends@dependencies[[i]]@outputObjects,
-                           eval(pf[[1]][[3]][outObjs][[1]]))
+                           evald)
             )
           )
         }
 
         # add child modules to list of all child modules, to be parsed later
-        children <- as.list(sim@depends@dependencies[[i]]@childModules) %>%
-          lapply(., `attributes<-`, list(parsed = FALSE))
+        children <- as.list(sim@depends@dependencies[[i]]@childModules) |>
+          lapply(`attributes<-`, list(parsed = FALSE))
         names(children) <- file.path(dirname(m), children)
         all_children <- append_attr(all_children, children)
 
@@ -469,8 +477,8 @@ setMethod(
       } else {
         alreadyIn <- names(sim@depends@dependencies) %in% mBase
         if (any(alreadyIn)) {
-          children <- as.list(sim@depends@dependencies[[which(alreadyIn)]]@childModules) %>%
-            lapply(., `attributes<-`, list(parsed = FALSE))
+          children <- as.list(sim@depends@dependencies[[which(alreadyIn)]]@childModules) |>
+            lapply(`attributes<-`, list(parsed = FALSE))
           names(children) <- file.path(dirname(m), children)
           all_children <- append_attr(all_children, children)
         }
@@ -620,7 +628,8 @@ evalWithActiveCode <- function(parsedModuleNoDefineModule, envir, parentFrame =
     #                                  silent = TRUE, error = function(x) FALSE))
     # if (isFALSE(isPack)) {
       if (!isAbsolutePath(fullModulePath)) {
-        fullModulePath <- file.path(modulePath(sim), fullModulePath)
+        fullModulePath <- file.path(modulePath(sim), fullModulePath) ## may be length > 1
+        fullModulePath <- fullModulePath[dir.exists(fullModulePath)]
       }
       isPack <- file.exists(file.path(fullModulePath, "DESCRIPTION"))
     #}
