@@ -1,4 +1,4 @@
-SpaDES.core.version <- "1.0.7"
+SpaDES.core.version <- "2.0.0"
 if (utils::packageVersion("SpaDES.core") < SpaDES.core.version) {
   stop("This 'randomLandscapes' module was built with 'SpaDES.core' version",
        SpaDES.core.version, ".\n",
@@ -7,7 +7,7 @@ if (utils::packageVersion("SpaDES.core") < SpaDES.core.version) {
 rm(SpaDES.core.version)
 
 ## this version of the 'randomLandscapes' module loads data from file instead of
-## generating it using 'SpaDES.tools::gaussMap'
+## generating it using 'SpaDES.tools::neutralLandscapeMap'
 
 defineModule(sim, list(
   name = "randomLandscapes",
@@ -23,21 +23,20 @@ defineModule(sim, list(
            role = c("aut", "cre"))
   ),
   version = list(randomLandscapes = "1.7.0"),
-  spatialExtent = raster::extent(rep(NA_real_, 4)),
+  spatialExtent = terra::ext(rep(0, 4)),
   timeframe = as.POSIXlt(c(NA, NA)),
   timeunit = "year",
   citation = list(),
   documentation = list(),
-  reqdPkgs = list(
-    "ropensci/NLMR",
-    "raster", "RColorBrewer",
-    "PredictiveEcology/SpaDES.tools@development"
-  ),
+  reqdPkgs = list("ropensci/NLMR (>= 1.1.1)", "terra", "RColorBrewer", "reproducible (>= 2.0.2)",
+                  "SpaDES.tools (>= 2.0.0)"),
   parameters = rbind(
     defineParameter("inRAM", "logical", FALSE, TRUE, FALSE, "should the raster be stored in memory?"),
     defineParameter("nx", "numeric", 100L, 10L, 500L, "size of map (number of pixels) in the x dimension"),
     defineParameter("ny", "numeric", 100L, 10L, 500L, "size of map (number of pixels) in the y dimension"),
     defineParameter("stackName", "character", "landscape", NA, NA, "name of the RasterStack"),
+    defineParameter(".plots", "character", "screen", NA, NA,
+                    "A modular mechanism to create plots, using png, screen device or other. See ?Plots."),
     defineParameter(".plotInitialTime", "numeric", start(sim), start(sim), NA, "time to schedule first plot event"),
     defineParameter(".plotInterval", "numeric", NA_real_, NA, NA, "time interval between plot events"),
     defineParameter(".saveInitialTime", "numeric", NA_real_, NA, NA, "time to schedule first save event"),
@@ -46,7 +45,9 @@ defineModule(sim, list(
                     paste("Named list of seeds to use for each event (names).",
                           "E.g., `list('init' = 123)` will `set.seed(123)`",
                           "for the `init` event only.")),
-    defineParameter(".useCache", "logical", FALSE, c("init", "plot"), NA, "should the module result be cached for future use")
+    defineParameter(".useCache", "logical", FALSE, NA, NA,
+                    "Should the module (or it's events) be cached for future use? Accepts logical",
+                    "or a vector of events to cache.")
   ),
   inputObjects = bindrows(
     expectsInput(objectName = NA_character_, objectClass = NA_character_,
@@ -54,7 +55,7 @@ defineModule(sim, list(
   ),
   outputObjects = bindrows(
     createsOutput(objectName = SpaDES.core::P(sim, module = "randomLandscapes")$stackName,
-                  objectClass = "RasterStack",
+                  objectClass = "SpatRaster",
                   desc = paste("NOTE: resulting stack may be slightly smaller than specified",
                                "because `nlm_mpd()` may drop pixels along raster edges."))
   )
@@ -69,20 +70,20 @@ doEvent.randomLandscapes <- function(sim, eventTime, eventType, debug = FALSE) {
       sim <- Init(sim)
 
       # schedule the next events
-      sim <- scheduleEvent(sim, SpaDES.core::P(sim)$.plotInitialTime, "randomLandscapes", "plot", .last())
-      sim <- scheduleEvent(sim, SpaDES.core::P(sim)$.saveInitialTime, "randomLandscapes", "save", .last() + 1)
+      sim <- scheduleEvent(sim, Par$.plotInitialTime, "randomLandscapes", "plot", .last())
+      sim <- scheduleEvent(sim, Par$.saveInitialTime, "randomLandscapes", "save", .last() + 1)
     },
     plot = {
       # do stuff for this event
-      stackName <- SpaDES.core::P(sim)$stackName ## Plot doesn't like long variables
-      Plot(sim[[stackName]])
+      Plots(sim[[Par$stackName]], usePlot = TRUE)
     },
     save = {
       # do stuff for this event
       sim <- saveFiles(sim)
 
       # schedule the next event
-      sim <- scheduleEvent(sim, time(sim) + SpaDES.core::P(sim)$.saveInterval, "randomLandscapes", "save", .last() + 1)
+      sim <- scheduleEvent(sim, time(sim) + Par$.saveInterval, "randomLandscapes",
+                           "save", .last() + 1)
     },
     warning(paste(
       "Undefined event type: \'", events(sim)[1, "eventType", with = FALSE],
@@ -94,76 +95,65 @@ doEvent.randomLandscapes <- function(sim, eventTime, eventType, debug = FALSE) {
 
 ## event functions
 Init <- function(sim) {
-  if (is.null(SpaDES.core::P(sim)$inRAM)) {
+  if (is.null(Par$inRAM)) {
     inMemory <- FALSE
   } else {
-    inMemory <- SpaDES.core::P(sim)$inRAM
+    inMemory <- Par$inRAM
   }
+
   ## Give dimensions of dummy raster
-  nx <- SpaDES.core::P(sim)$nx
-  ny <- SpaDES.core::P(sim)$ny
-  template <- raster(nrows = ny, ncols = nx, xmn = -nx / 2, xmx = nx / 2,
-                     ymn = -ny / 2, ymx = ny / 2)
+  nx <- Par$nx
+  ny <- Par$ny
+  template <- rast(nrows = ny, ncols = nx, xmin = -nx / 2, xmax = nx / 2, ymin = -ny / 2, ymax = ny / 2)
 
   ## Make dummy maps for testing of models
-  ## NOTE: nlm_mpd drops row + columns along outer edge so new raster won't always match nx & ny
+  DEM <- SpaDES.tools::neutralLandscapeMap(template,
+                                           roughness = 0.3,
+                                           rand_dev = 10,
+                                           rescale = TRUE,
+                                           verbose = FALSE)
 
-  # DEM <- gaussMap(template, scale = 10, var = 0.03, speedup = speedup, inMemory = inMemory)
-  DEM <- NLMR::nlm_mpd(
-    ncol = ncol(template),
-    nrow = nrow(template),
-    resolution = unique(res(template)),
-    roughness = 0.3,
-    rand_dev = 10,
-    rescale = TRUE,
-    verbose = FALSE
-  )
-  DEM[] <- round(getValues(DEM), 1) * 300
-  # plot(DEM)
+  DEM[] <- round(values(DEM), 1) * 300
+  # terra::plot(DEM)
 
-  # forestAge <- gaussMap(template, scale = 10, var = 0.1, speedup = speedup, inMemory = inMemory)
-  forestAge <- NLMR::nlm_mpd(
-    ncol = ncol(template),
-    nrow = nrow(template),
-    resolution = unique(res(template)),
-    roughness = 0.7,
-    rand_dev = 10,
-    rescale = FALSE,
-    verbose = FALSE
-  )
-  forestAge[] <- round(getValues(forestAge), 1) * 10
-  # plot(forestAge)
+  forestAge <- SpaDES.tools::neutralLandscapeMap(template,
+                                                 roughness = 0.7,
+                                                 rand_dev = 10,
+                                                 rescale = FALSE,
+                                                 verbose = FALSE)
 
-  # percentPine <- gaussMap(template, scale = 10, var = 1, speedup = speedup, inMemory = inMemory)
-  percentPine <- NLMR::nlm_mpd(
-    ncol = ncol(template),
-    nrow = nrow(template),
-    resolution = unique(res(template)),
-    roughness = 0.5,
-    rand_dev = 10,
-    rescale = TRUE,
-    verbose = FALSE
-  )
-  percentPine[] <- round(getValues(percentPine), 1)
-  # plot(percentPine)
+  forestAge[] <- round(values(forestAge), 1) * 10
+  # terra::plot(forestAge)
+
+  percentPine <- SpaDES.tools::neutralLandscapeMap(template,
+                                                   roughness = 0.5,
+                                                   rand_dev = 10,
+                                                   rescale = TRUE,
+                                                   verbose = FALSE)
+
+  percentPine[] <- round(values(percentPine), 1)
+  # terra::plot(percentPine)
 
   ## Scale them as needed
-  forestAge <- forestAge + abs(minValue(forestAge))
-  forestAge <- forestAge / maxValue(forestAge) * 100
-  percentPine <- percentPine / maxValue(percentPine) * 100
+  forestAge <- forestAge + abs(minFn(forestAge))
+  forestAge <- forestAge / maxFn(forestAge) * 100
+  percentPine <- percentPine / maxFn(percentPine) * 100
 
   # Make layers that are derived from other layers
   habitatQuality <- (DEM + 10 + (forestAge + 2.5) * 10) / 100
-  habitatQuality <- habitatQuality / maxValue(habitatQuality)
+  habitatQuality <- habitatQuality / maxFn(habitatQuality)
 
   # Stack them into a single stack and assign to global env
-  mapStack <- raster::stack(DEM, forestAge, habitatQuality, percentPine)
+  mapStack <- c(DEM, forestAge, habitatQuality, percentPine)
   names(mapStack) <- c("DEM", "forestAge", "habitatQuality", "percentPine")
 
-  setColors(mapStack) <- list(DEM = brewer.pal(9, "YlOrBr"),
-                              forestAge = brewer.pal(9, "BuGn"),
-                              habitatQuality = brewer.pal(8, "Spectral"),
-                              percentPine = brewer.pal(9, "Greens"))
-  sim[[SpaDES.core::P(sim)$stackName]] <- mapStack
+  cols <- list(DEM = brewer.pal(9, "YlOrBr"),
+               forestAge = brewer.pal(9, "BuGn"),
+               habitatQuality = brewer.pal(8, "Spectral"),
+               percentPine = brewer.pal(9, "Greens"))
+  for (i in seq(cols))
+    coltab(mapStack, layer = i) <- cols[[i]]
+
+  sim[[Par$stackName]] <- mapStack
   return(invisible(sim))
 }
