@@ -1,7 +1,7 @@
 test_that("simList object initializes correctly (1)", {
   testInit(sampleModReqdPkgs)
 
-  defaults <- .coreModules() %>% unname()
+  defaults <- .coreModules() |> unname()
   times <- list(start = 1.0, end = 10)
   params <- list(
     .globals = list(burnStats = "npixelsburned", stackName = "landscape")
@@ -35,7 +35,7 @@ test_that("simList object initializes correctly (1)", {
   options(width = 100L)
   out <- utils::capture.output(show(mySim))
 
-  expect_equal(length(out), 77)
+  expect_equal(length(out), 81)
   options(width = w)
   rm(w)
 
@@ -97,8 +97,7 @@ test_that("simList object initializes correctly (1)", {
   # checkpoint
   expect_true(is.null(checkpointFile(mySim)))
   checkpointFile(mySim) <- file.path(outputPath(mySim), "checkpoint.RData")
-  expect_identical(checkpointFile(mySim),
-                   file.path(outputPath(mySim), "checkpoint.RData"))
+  expect_identical(checkpointFile(mySim), file.path(outputPath(mySim), "checkpoint.RData"))
 
   expect_true(is.na(checkpointInterval(mySim)))
   checkpointInterval(mySim) <- 10
@@ -129,7 +128,7 @@ test_that("simList object initializes correctly (1)", {
 
   ### SLOT completed
   expect_is(completed(mySim), "data.table")
-  expect_equal(nrow(completed(mySim)), 0)
+  expect_equal(nrow(completed(mySim)), 3) ## .inputObjects for each module have run
 
   ### SLOT depends
   expect_is(depends(mySim), ".simDeps")
@@ -162,7 +161,7 @@ test_that("simList object initializes correctly (1)", {
 
   expect_equivalent(end(mySim)   <- 20, 20.0)
   expect_equivalent(start(mySim) <- 10, 10.0)
-  expect_equivalent(time(mySim)  <- 10, 10.0)
+  expect_equivalent(time(mySim), 1.0)
 
   expect_equal(timeunit(mySim), attr(end(mySim), "unit"))
   expect_equal(timeunit(mySim), attr(start(mySim), "unit"))
@@ -180,20 +179,20 @@ test_that("simList object initializes correctly (1)", {
   reqdPkgs <- lapply(modules, function(m) {
     mfile <- file.path(getSampleModules(tmpdir), m, paste0(m, ".R"))
     packages(filename = mfile)
-  }) %>%
-    unlist() %>%
-    sort() %>%
-    SpaDES.core:::.cleanPkgs() %>%
+  }) |>
+    unlist() |>
+    sort() |>
+    SpaDES.core:::.cleanPkgs() |>
     unique()
   expect_equal(sort(reqdPkgs), sort(pkgs))
 
   mdir <- getOption("spades.modulePath")
   options(spades.modulePath = getSampleModules(tmpdir))
   on.exit(options(spades.modulePath = mdir), add = TRUE)
-  reqdPkgs <- lapply(modules, function(m) packages(module = m)) %>%
-    unlist() %>%
-    sort() %>%
-    SpaDES.core:::.cleanPkgs() %>%
+  reqdPkgs <- lapply(modules, function(m) packages(module = m)) |>
+    unlist() |>
+    sort() |>
+    SpaDES.core:::.cleanPkgs() |>
     unique()
   expect_equal(sort(reqdPkgs), sort(pkgs))
 
@@ -230,10 +229,11 @@ test_that("simList test all signatures", {
       setPaths(modulePath = origDir)
     }
   }, add = TRUE)
-  # times
+
+  ## times
   times <- list(start = 0.0, end = 10)
 
-  # modules
+  ## modules
   modules <- list("randomLandscapes")#, "caribouMovement", "fireSpread")
   curPathIsPkgPath <- (identical(
     normPath(getSampleModules(tmpdir)),
@@ -247,7 +247,7 @@ test_that("simList test all signatures", {
     setPaths(modulePath = getwd())
   }
 
-  # paths
+  ## paths
   mapPath <- getMapPath(tmpdir)
   paths <- list(
     modulePath = getSampleModules(tmpdir),
@@ -255,7 +255,7 @@ test_that("simList test all signatures", {
     outputPath = tempdir()
   )
 
-  # inputs
+  ## inputs
   filelist <- data.frame(
     files = dir(file.path(mapPath), full.names = TRUE, pattern = "tif")[1:2],
     functions = "rast",
@@ -264,21 +264,21 @@ test_that("simList test all signatures", {
     stringsAsFactors = FALSE
   )
 
-  # objects
+  ## objects
   layers <- lapply(filelist$files, rasterToMemory)
   DEM <- layers[[1]]
   forestAge <- layers[[2]]
   objects <- list(DEM = "DEM", forestAge = "forestAge")
   objectsChar <- c("DEM", "forestAge")
 
-  # outputs
+  ## outputs
   outputs <- data.frame(
     expand.grid(objectName = c("caribou", "landscape"),
                 saveTime = 1:2,
                 stringsAsFactors = FALSE)
   )
 
-  # parameters
+  ## parameters
   parameters <- list(
     caribouMovement = list(.plotInitialTime = NA),
     randomLandscapes = list(.plotInitialTime = NA, nx = 20, ny = 20)
@@ -287,11 +287,11 @@ test_that("simList test all signatures", {
   # loadOrder
   loadOrder <- c("randomLandscapes")#, "caribouMovement", "fireSpread")
 
-  # test all argument combinations to simInit
+  ## test all argument combinations to simInit
   N <- 256L
   successes <- logical(N)
   argsTested <- vector("list", length = N)
-  # setPaths(inputPath = NULL, outputPath = NULL, modulePath = NULL, cachePath = NULL)
+  ## setPaths(inputPath = NULL, outputPath = NULL, modulePath = NULL, cachePath = NULL)
   for (i in 1L:N) {
     li <- list(
       {if (i %% 2 ^ 1 == 0) times = times},                   # nolint
@@ -307,15 +307,16 @@ test_that("simList test all signatures", {
                   "outputs", "loadOrder")
     names(li) <- argNames
     li <- li[!sapply(li, is.null)]
-    messes <- capture_messages(successes[i] <- tryCatch(
-      is(suppressMessages(do.call(simInit, args = li)), "simList"),
-      error = function(e) { FALSE },
-      warning = function(w) { TRUE }
-    ))
+    messes <- capture_messages({
+      successes[i] <- tryCatch({
+          is(suppressMessages(do.call(simInit, args = li)), "simList")
+        }, error = function(e) { FALSE }, warning = function(w) { TRUE }
+      )
+    })
     argsTested[[i]] <- names(li)
   }
 
-  # needs paths and params; many defaults are fine
+  ## needs paths and params; many defaults are fine
   expect_equal(sum(successes, na.rm = TRUE), 256)
   if (FALSE) {
     dt <- data.table(lapply(argsTested, paste, collapse = "_"), successes)
@@ -353,8 +354,8 @@ test_that("test that module directory exists, but not files", {
   paths <- getPaths()
   modules <- list(parentModName)
   times <- list(start = 1, end = 10)
-  mainChildModuleFile <- file.path(paths$modulePath, childModName, paste0(childModName, ".R") )
-  mainParentModuleFile <- file.path(paths$modulePath, parentModName, paste0(parentModName, ".R") )
+  mainChildModuleFile <- file.path(paths$modulePath, childModName, paste0(childModName, ".R"))
+  mainParentModuleFile <- file.path(paths$modulePath, parentModName, paste0(parentModName, ".R"))
   expect_true(file.exists(mainChildModuleFile))
 
   file.remove(mainChildModuleFile)
@@ -383,7 +384,7 @@ test_that("test that module directory exists, but not files", {
 test_that("inputObjects on module arg not sim", {
   testInit(sampleModReqdPkgs)
 
-  defaults <- .coreModules() %>% unname()
+  defaults <- .coreModules() |> unname()
   times <- list(start = 1.0, end = 10)
   params <- list(
     .globals = list(burnStats = "npixelsburned", stackName = "landscape")
@@ -404,3 +405,119 @@ test_that("inputObjects on module arg not sim", {
     expect_true(all.equal(setDF(io[[m]][, -1]), io1[[m]][, -1]))
   })
 })
+
+test_that("test sped-up Caching of sequentially cached events", {
+  testInit(sampleModReqdPkgs, opts = list(spades.allowSequentialCaching = TRUE))
+  withr::local_options(list(reproducible.cachePath = tmpdir))
+
+  defaults <- .coreModules() |> unname()
+  times <- list(start = 1.0, end = 10)
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+    randomLandscapes = list(.useCache = c("init", ".inputObjects"),
+                            nx = 100, ny = 100),
+    fireSpread = list(.useCache = c("init", ".inputObjects")),
+    caribouMovement = list(.useCache = c("init", ".inputObjects"))
+
+  )
+  modules <- list("randomLandscapes", "fireSpread", "caribouMovement")
+  paths <- list(modulePath = getSampleModules(tmpdir))
+
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_false(any(grepl("Skipped digest", mess)))
+
+  ## Rerun with Cached copies being recovered
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_true(sum(grepl("Skipped digest", mess)) == 2)
+
+  ## If they are not sequential, shouldn't do it
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+    randomLandscapes = list(.useCache = c("init", ".inputObjects")),
+    caribouMovement = list(.useCache = c("init", ".inputObjects"))
+  )
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_false(any(grepl("Skipped digest", mess)))
+
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_false(any(grepl("Skipped digest", mess)))
+
+  ## If they are different sequential, should do it
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+    randomLandscapes = list(.useCache = c("init", ".inputObjects")),
+    fireSpread = list(.useCache = c("init", ".inputObjects"))
+    # caribouMovement = list(.useCache = c("init", ".inputObjects"))
+  )
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_false(sum(grepl("Skipped digest", mess)) == 1)
+
+  mySim <- simInit(times, params, modules, objects = list(), paths)
+  mess <- capture_messages({
+    mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+  })
+  expect_true(sum(grepl("Skipped digest", mess)) == 1)
+})
+
+test_that("test sped-up Caching of sequentially cached events", {
+  testInit(sampleModReqdPkgs, opts = list(spades.allowSequentialCaching = TRUE))
+  withr::local_options(list(reproducible.cachePath = tmpdir))
+
+  defaults <- .coreModules() |> unname()
+  times <- list(start = 1.0, end = 10)
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+    randomLandscapes = list(.useCache = c("init", ".inputObjects"),
+                            nx = 100, ny = 100),
+    fireSpread = list(.useCache = c("init", ".inputObjects")),
+    caribouMovement = list(.useCache = c("init", ".inputObjects"))
+
+  )
+  modules <- list("randomLandscapes", "fireSpread", "caribouMovement")
+  paths <- list(modulePath = getSampleModules(tmpdir))
+
+  for (i in 2:3) {
+    fn <- file.path(paths$modulePath, modules[i], paste0(modules[i], ".R"))
+    xxx1 <- c(readLines(fn),
+              ".inputObjects <- function(sim) {",
+              "  a = asPath(file.path(inputPath(sim), \"test\")) ",
+              paste0("  if (!suppliedElsewhere(", params$.globals$stackName, "))"),
+              paste0("  sim[[", params$.globals$stackName, "]] <- sim[[", params$.globals$stackName, "]]"),
+              "sim",
+              "}")
+
+    cat(xxx1, file = fn, sep = "\n")
+  }
+
+  ## Run first time to create the caches
+  for (i in 1:2) {
+    mess1 <- capture_messages({
+      mySim <- simInit(times, params, modules, objects = list(), paths, debug = 1)
+    })
+    mess <- capture_messages({
+      mySimOut <- spades(mySim, debug = 1, .plotInitialTime = NA)
+    })
+    if (i == 1) {
+      expect_equal(sum(grepl("Skipped digest", mess)), 0)
+      expect_equal(sum(grepl("Skipped digest", mess1)), 0)
+    } else {
+      expect_equal(sum(grepl("Skipped digest", mess)), 3)
+      expect_equal(sum(grepl("Skipped digest", mess1)), 1) # there is no .inputObjects for randomLandscapes
+    }
+  }
+})
